@@ -10,7 +10,7 @@ from databind.core.settings import Alias, ExtraKeys
 
 from slap.application import Application, Command, argument, option
 from slap.changelog import Changelog, ChangelogEntry, ChangelogManager, ManagedChangelog
-from slap.plugins import ApplicationPlugin, GitRepositoryHostPlugin
+from slap.plugins import ApplicationPlugin, RepositoryCIPlugin
 from slap.project import Project
 from slap.repository import Issue, PullRequest, Repository
 from slap.util.pygments import toml_highlight
@@ -33,9 +33,17 @@ DEFAULT_VALID_TYPES = [
 
 
 def get_default_author(app: Application) -> str | None:
-    vcs = app.repository.vcs()
-    remote = app.repository.host()
-    return remote.get_username(app.repository) if remote else vcs.get_author().email if vcs else None
+    username: str | None = None
+    if remote := app.repository.host():
+        try:
+            username = remote.get_username(app.repository)
+        except Exception as exc:
+            logger.warning(
+                f"unable to fetch GitHub username, falling back to configured email address. (reason: {exc})"
+            )
+    if username is None and (vcs := app.repository.vcs()):
+        username = vcs.get_author().email
+    return username
 
 
 @ExtraKeys(True)
@@ -92,12 +100,12 @@ class ChangelogAddCommand(BaseChangelogCommand):
       <fg=green>author</fg> = <fg=yellow>"username"</fg>
       <fg=green>pr</fg> = <fg=yellow>"https://github.com/username/my_package/pulls/13"</fg>
 
-    Changelog entries can be managed easily using the <info>slap log</info> command.
+    Changelog entries can be managed easily using the <info>slap changelog</info> command.
 
-      <fg=yellow>$</fg> slap log add -t feature -d 'Improvement to `my_package.util`"
+      <fg=yellow>$</fg> slap changelog add -t feature -d 'Improvement to `my_package.util`"
 
     The <fg=green>pr</fg> field is usually set manually after the PR is created or updated
-    automatically by a CI action using the <info>slap log update-pr-field</info> command.
+    automatically by a CI action using the <info>slap changelog update-pr-field</info> command.
     """
 
     name = "changelog add"
@@ -106,8 +114,8 @@ class ChangelogAddCommand(BaseChangelogCommand):
         option(
             "--type",
             "-t",
-            description="The type of the changelog. Unless configured differently, one of "
-            "{', '.join(DEFAULT_VALID_TYPES)}",
+            description="The type of the changelog. Unless configured differently, one of: "
+            f"{', '.join(DEFAULT_VALID_TYPES)}",
             flag=False,
         ),
         option(
@@ -237,7 +245,7 @@ class ChangelogDiffBaseCommand(Command):
             config: get_changelog_manager(app.repository, config if isinstance(config, Project) else None)
             for config in app.configurations()
         }
-        self.git_host: GitRepositoryHostPlugin | None
+        self.ci: RepositoryCIPlugin | None
         self.base_ref: str
         self.head_ref: str | None
         self.vcs: Vcs
@@ -249,12 +257,12 @@ class ChangelogDiffBaseCommand(Command):
         if plugin_name is not None:
             logger.info("Loading changelog update automation plugin <i>%s</i>", plugin_name)
             try:
-                self.git_host = GitRepositoryHostPlugin.get(plugin_name, self.io)
+                self.ci = RepositoryCIPlugin.get(plugin_name, self.io)
             except ValueError:
                 self.line_error(f"plugin `<info>{plugin_name}</info>` does not exist.", "error")
                 sys.exit(1)
         else:
-            self.git_host = None
+            self.ci = None
 
         ref_or_range: str | None = self.argument("ref_or_range")
         if ref_or_range is not None:
@@ -265,11 +273,11 @@ class ChangelogDiffBaseCommand(Command):
             self.base_ref = base_revision
             self.head_ref = head_revision or None
         else:
-            if self.git_host is None:
+            if self.ci is None:
                 self.line_error("Need a base Git ref, Git range or set the --use option.", "error")
                 sys.exit(1)
-            self.base_ref = self.git_host.get_base_ref()
-            self.head_ref = self.git_host.get_head_ref()
+            self.base_ref = self.ci.get_base_ref()
+            self.head_ref = self.ci.get_head_ref()
 
         if self.head_ref is None:
             self.ref_range = f"{self.base_ref}..WORKTREE"
@@ -354,10 +362,10 @@ class ChangelogDiffUpdatePrCommand(ChangelogDiffBaseCommand):
 
         pr_url: str | None = self.option("pr")
         if pr_url is None:
-            if self.git_host is None:
+            if self.ci is None:
                 self.line_error("need <opt>--pr</opt> or <opt>--use</opt>", "error")
                 sys.exit(1)
-            pr_url = self.git_host.get_pr()
+            pr_url = self.ci.get_pr()
         self.pr_url = pr_url
 
     def handle(self) -> int:
@@ -396,10 +404,10 @@ class ChangelogDiffUpdatePrCommand(ChangelogDiffBaseCommand):
             self.line("no entries to update", "info")
             return 0
 
-        if self.git_host and not self.option("dry"):
+        if self.ci and not self.option("dry"):
             plural = "" if total_updates == 0 else "s"
             commit_message = f"Updated PR reference{plural} in {num_updates} changelog{plural}."
-            self.git_host.publish_changes(changed_files, commit_message)
+            self.ci.publish_changes(changed_files, commit_message)
 
         return 0
 
@@ -522,7 +530,9 @@ class ChangelogFormatCommand(BaseChangelogCommand):
                 text = "Link"
             else:
                 url, text = item.url, item.id
-        return f'<a href="{url}">{text}</a>'
+            return f'<a href="{url}">{text}</a>'
+        else:
+            return ref
 
 
 class ChangelogConvertCommand(BaseChangelogCommand):
